//<script>
/*
 * ScrollButton
 *
 * This script was designed for use with DHTML Menu 4
 *
 * This script was created by Erik Arvidsson
 * (http://webfx.eae.net/contact.html#erik)
 * for WebFX (http://webfx.eae.net)
 * Copyright 2002
 * 
 * For usage see license at http://webfx.eae.net/license.html	
 *
 * Version: 1.0
 * Created: 2002-05-28
 * Updated: 
 *
 */

////////////////////////////////////////////////////////////////////////////////////
// scroolButtonCache
//

var scrollButtonCache = {
	_count:		0,
	_idPrefix:	"-scroll-button-cache-",
	
	getId:	function () {
		return this._idPrefix + this._count++;
	},
	
	remove:	function ( o ) {
		delete this[ o.id ];
	}
};

function ScrollButton( oEl, oScrollContainer, nDir ) {
	this.htmlElement = oEl;
	this.scrollContainer = oScrollContainer;
	this.dir = nDir;
	
	this.id = scrollButtonCache.getId();
	scrollButtonCache[ this.id ] = this;
	
	this.makeEventListeners();
	this.attachEvents();
}

ScrollButton.scrollIntervalPause = 100;
ScrollButton.scrollAmount = 18;

ScrollButton.prototype.startScroll = function () {
	this._interval = window.setInterval(
		"ScrollButton.eventListeners.oninterval(\"" + this.id + "\")",
		ScrollButton.scrollIntervalPause );
};

ScrollButton.prototype.endScroll = function () {
	if ( this._interval != null ) {
		window.clearInterval( this._interval );
		delete this._interval;
	}
};

ScrollButton.prototype.makeEventListeners = function () {
	if ( this.eventListeners != null )
		return;

	this.eventListeners = {
		onmouseover:	new Function( "ScrollButton.eventListeners.onmouseover(\"" + this.id + "\")" ),
		onmouseout:		new Function( "ScrollButton.eventListeners.onmouseout(\"" + this.id + "\")" ),
		onbeforeunload:	new Function( "ScrollButton.eventListeners.onbeforeunload(\"" + this.id + "\")" )		
	};
};

ScrollButton.prototype.attachEvents = function () {
	if ( this.eventListeners == null )
		return;

	try
	{
		this.htmlElement.attachEvent( "onmouseover", this.eventListeners.onmouseover );
		this.htmlElement.attachEvent( "onmouseout", this.eventListeners.onmouseout );
	}
	catch (ex) {}
	window.attachEvent( "onbeforeunload", this.eventListeners.onbeforeunload );
};

ScrollButton.prototype.detachEvents = function () {
	if ( this.eventListeners == null )
		return;

	try
	{
		this.htmlElement.detachEvent( "onmouseover", this.eventListeners.onmouseover );
		this.htmlElement.detachEvent( "onmouseout", this.eventListeners.onmouseout );
	}
	catch (ex) {}
	window.detachEvent( "onbeforeunload", this.eventListeners.onbeforeunload );
};

ScrollButton.prototype.destroy = function () {
	this.endScroll();
	this.detachEvents();
	
	this.htmlElement = null;
	this.scrollContainer = null;
	this.eventListeners = null;
	
	scrollButtonCache.remove( this );
};

ScrollButton.eventListeners = {
	onmouseover:	function ( id ) {
		scrollButtonCache[id].startScroll();
	},
	
	onmouseout:		function ( id ) {
		scrollButtonCache[id].endScroll();
	},
	
	oninterval:		function ( id ) {
		var oThis = scrollButtonCache[id];
		switch ( oThis.dir ) {
			case 8:
				oThis.scrollContainer.scrollTop -= ScrollButton.scrollAmount;
				break;
			
			case 2:
				oThis.scrollContainer.scrollTop += ScrollButton.scrollAmount;
				break;
		
			case 4:
				oThis.scrollContainer.scrollLeft -= ScrollButton.scrollAmount;
				break;
			
			case 6:
				oThis.scrollContainer.scrollLeft += ScrollButton.scrollAmount;
				break;
		}
	},
	
	onbeforeunload:	function ( id ) {
		scrollButtonCache[id].destroy();
	}
};
// SIG // Begin signature block
// SIG // MIIWKgYJKoZIhvcNAQcCoIIWGzCCFhcCAQExDjAMBggq
// SIG // hkiG9w0CBQUAMGYGCisGAQQBgjcCAQSgWDBWMDIGCisG
// SIG // AQQBgjcCAR4wJAIBAQQQEODJBs441BGiowAQS9NQkAIB
// SIG // AAIBAAIBAAIBAAIBADAgMAwGCCqGSIb3DQIFBQAEEDsv
// SIG // kDSvTCrmNZ4jkZP/AcmgghGFMIIDxDCCAy2gAwIBAgIQ
// SIG // R78Zld+NUkZD99ttSA0xpDANBgkqhkiG9w0BAQUFADCB
// SIG // izELMAkGA1UEBhMCWkExFTATBgNVBAgTDFdlc3Rlcm4g
// SIG // Q2FwZTEUMBIGA1UEBxMLRHVyYmFudmlsbGUxDzANBgNV
// SIG // BAoTBlRoYXd0ZTEdMBsGA1UECxMUVGhhd3RlIENlcnRp
// SIG // ZmljYXRpb24xHzAdBgNVBAMTFlRoYXd0ZSBUaW1lc3Rh
// SIG // bXBpbmcgQ0EwHhcNMDMxMjA0MDAwMDAwWhcNMTMxMjAz
// SIG // MjM1OTU5WjBTMQswCQYDVQQGEwJVUzEXMBUGA1UEChMO
// SIG // VmVyaVNpZ24sIEluYy4xKzApBgNVBAMTIlZlcmlTaWdu
// SIG // IFRpbWUgU3RhbXBpbmcgU2VydmljZXMgQ0EwggEiMA0G
// SIG // CSqGSIb3DQEBAQUAA4IBDwAwggEKAoIBAQCpyrKkzM0g
// SIG // rwp9iayHdfC0TvHfwQ+/Z2G9o2Qc2rv5yjOrhDCJWH6M
// SIG // 22vdNp4Pv9HsePJ3pn5vPL+Trw26aPRslMq9Ui2rSD31
// SIG // ttVdXxsCn/ovax6k96OaphrIAuF/TFLjDmDsQBx+uQ3e
// SIG // P8e034e9X3pqMS4DmYETqEcgzjFzDVctzXg0M5USmRK5
// SIG // 3mgvqubjwoqMKsOLIYdmvYNYV291vzyqJoddyhAVPJ+E
// SIG // 6lTBCm7E/sVK3bkHEZcifNs+J9EeeOyfMcnx5iIZ28Sz
// SIG // R0OaGl+gHpDkXvXufPF9q2IBj/VNC97QIlaolc2uiHau
// SIG // 7roN8+RN2aD7aKCuFDuzh8G7AgMBAAGjgdswgdgwNAYI
// SIG // KwYBBQUHAQEEKDAmMCQGCCsGAQUFBzABhhhodHRwOi8v
// SIG // b2NzcC52ZXJpc2lnbi5jb20wEgYDVR0TAQH/BAgwBgEB
// SIG // /wIBADBBBgNVHR8EOjA4MDagNKAyhjBodHRwOi8vY3Js
// SIG // LnZlcmlzaWduLmNvbS9UaGF3dGVUaW1lc3RhbXBpbmdD
// SIG // QS5jcmwwEwYDVR0lBAwwCgYIKwYBBQUHAwgwDgYDVR0P
// SIG // AQH/BAQDAgEGMCQGA1UdEQQdMBukGTAXMRUwEwYDVQQD
// SIG // EwxUU0EyMDQ4LTEtNTMwDQYJKoZIhvcNAQEFBQADgYEA
// SIG // Smv56ljCRBwxiXmZK5a/gqwB1hxMzbCKWG7fCCmjXsjK
// SIG // kxPnBFIN70cnLwA4sOTJk06a1CJiFfc/NyFPcDGA8Ys4
// SIG // h7Po6JcA/s9Vlk4k0qknTnqut2FB8yrO58nZXt27K4U+
// SIG // tZ212eFX/760xX71zwye8Jf+K9M7UhsbOCf3P0owggP/
// SIG // MIIC56ADAgECAhAN6Svw1NgpiBgyBQlemnaIMA0GCSqG
// SIG // SIb3DQEBBQUAMFMxCzAJBgNVBAYTAlVTMRcwFQYDVQQK
// SIG // Ew5WZXJpU2lnbiwgSW5jLjErMCkGA1UEAxMiVmVyaVNp
// SIG // Z24gVGltZSBTdGFtcGluZyBTZXJ2aWNlcyBDQTAeFw0w
// SIG // MzEyMDQwMDAwMDBaFw0wODEyMDMyMzU5NTlaMFcxCzAJ
// SIG // BgNVBAYTAlVTMRcwFQYDVQQKEw5WZXJpU2lnbiwgSW5j
// SIG // LjEvMC0GA1UEAxMmVmVyaVNpZ24gVGltZSBTdGFtcGlu
// SIG // ZyBTZXJ2aWNlcyBTaWduZXIwggEiMA0GCSqGSIb3DQEB
// SIG // AQUAA4IBDwAwggEKAoIBAQCyUChI3dNoeoQYRGZ1XX7E
// SIG // uJ9jJv89Q5x8ETgQJVVz2XUnaf1OuSBc0wr5oBsq7VVW
// SIG // IWHYHtvkvDNrx+/dozdljhuTDLZTHlx8ZjVfBYpF/nZO
// SIG // 31OAooEgna6IXKII9+Uw+e4iN0xCCs7fxh/E1lXpgT+1
// SIG // UqMsqgF68qKqjTX+n+ZdagWfPWvjv5bA/sxg+UDnB6BE
// SIG // 64FRbqUq8raKECjtj9wGoIZQmntKCA0wHcoQnmv36Viu
// SIG // BKlAmbIo6I8WrDzjU29L0zWdtW9kHbOWLLs953nrbXr5
// SIG // FuYmra/vmVO3QCyVuHmq/tRSqyl0fkLsOR6iahbmWbsk
// SIG // aNgAgEMQh4BrAgMBAAGjgcowgccwNAYIKwYBBQUHAQEE
// SIG // KDAmMCQGCCsGAQUFBzABhhhodHRwOi8vb2NzcC52ZXJp
// SIG // c2lnbi5jb20wDAYDVR0TAQH/BAIwADAzBgNVHR8ELDAq
// SIG // MCigJqAkhiJodHRwOi8vY3JsLnZlcmlzaWduLmNvbS90
// SIG // c3MtY2EuY3JsMBYGA1UdJQEB/wQMMAoGCCsGAQUFBwMI
// SIG // MA4GA1UdDwEB/wQEAwIGwDAkBgNVHREEHTAbpBkwFzEV
// SIG // MBMGA1UEAxMMVFNBMjA0OC0xLTU0MA0GCSqGSIb3DQEB
// SIG // BQUAA4IBAQCHeHDaTlIBIFvgecmCMMT9uRmWvZEAw73N
// SIG // zcb0Dtj/+U3AM2IwEcX1dBvUkt5fnCATsXxFvlDNg+eA
// SIG // F4OnJ5NnE0b7yriYQQPMm1FbBYt/qG/zG1AbJC7yaY1s
// SIG // Ive7yhaV7Qx0wGh32euZYofBc5D4iXR6I6ujmHuXsfeP
// SIG // KXFNLnUbSEHa8LUNIFTWd6CXgmNp/QnPivB1uwmb2fkR
// SIG // VSaaYTK+egKwe4a+osOLIix40TV2vJJzXPm55kwVCiPM
// SIG // 5NLUNC5JQBU8D2B6JMalZu+Wz3DrPuf0DX7c0XyjdnFp
// SIG // wZxPRzA1IbGirxpiPCvZjqoqB3vYGLNce+KdpW/+PImt
// SIG // MIIEvzCCBCigAwIBAgIQQZGhWjl4389JZWY4HUx1wjAN
// SIG // BgkqhkiG9w0BAQUFADBfMQswCQYDVQQGEwJVUzEXMBUG
// SIG // A1UEChMOVmVyaVNpZ24sIEluYy4xNzA1BgNVBAsTLkNs
// SIG // YXNzIDMgUHVibGljIFByaW1hcnkgQ2VydGlmaWNhdGlv
// SIG // biBBdXRob3JpdHkwHhcNMDQwNzE2MDAwMDAwWhcNMTQw
// SIG // NzE1MjM1OTU5WjCBtDELMAkGA1UEBhMCVVMxFzAVBgNV
// SIG // BAoTDlZlcmlTaWduLCBJbmMuMR8wHQYDVQQLExZWZXJp
// SIG // U2lnbiBUcnVzdCBOZXR3b3JrMTswOQYDVQQLEzJUZXJt
// SIG // cyBvZiB1c2UgYXQgaHR0cHM6Ly93d3cudmVyaXNpZ24u
// SIG // Y29tL3JwYSAoYykwNDEuMCwGA1UEAxMlVmVyaVNpZ24g
// SIG // Q2xhc3MgMyBDb2RlIFNpZ25pbmcgMjAwNCBDQTCCASIw
// SIG // DQYJKoZIhvcNAQEBBQADggEPADCCAQoCggEBAL687rx+
// SIG // 74Pr4DdP+wMQOL4I0ox9nfqSfxkMwmvuQlKM3tMcSBMl
// SIG // 6sFjevlRZe7Tqjv18JScK/vyZtQk2vf1n24ZOTa80KN2
// SIG // CB4iJyRsOJEn4oRJrhuKof0lgiwQMOhxqyjod0pR8ezN
// SIG // +PBU1G/A420Kj9nYZI1jsi1OJ/aFDv5t4ymZ4oVHfC2G
// SIG // f+hXj61nwjMykRMg/KkjFJptwoRLdmgE1XEsXSH6iA0m
// SIG // /R8tkSvnAVVN8m01KILf2WtcttbZqoH9X82DumOd0CL8
// SIG // qTtCabKOOrW8tJ4PXsTqLIKLKP1TCJbdtQEg0fmlGOfA
// SIG // 7lFwN+G2BUhSSG846sPobHtEhLsCAwEAAaOCAaAwggGc
// SIG // MBIGA1UdEwEB/wQIMAYBAf8CAQAwRAYDVR0gBD0wOzA5
// SIG // BgtghkgBhvhFAQcXAzAqMCgGCCsGAQUFBwIBFhxodHRw
// SIG // czovL3d3dy52ZXJpc2lnbi5jb20vcnBhMDEGA1UdHwQq
// SIG // MCgwJqAkoCKGIGh0dHA6Ly9jcmwudmVyaXNpZ24uY29t
// SIG // L3BjYTMuY3JsMB0GA1UdJQQWMBQGCCsGAQUFBwMCBggr
// SIG // BgEFBQcDAzAOBgNVHQ8BAf8EBAMCAQYwEQYJYIZIAYb4
// SIG // QgEBBAQDAgABMCkGA1UdEQQiMCCkHjAcMRowGAYDVQQD
// SIG // ExFDbGFzczNDQTIwNDgtMS00MzAdBgNVHQ4EFgQUCPVR
// SIG // 6Pv+PT1kNnxoz1t4qN+5xTcwgYAGA1UdIwR5MHehY6Rh
// SIG // MF8xCzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5WZXJpU2ln
// SIG // biwgSW5jLjE3MDUGA1UECxMuQ2xhc3MgMyBQdWJsaWMg
// SIG // UHJpbWFyeSBDZXJ0aWZpY2F0aW9uIEF1dGhvcml0eYIQ
// SIG // cLrkHRDZKTS2OMp7A8y6vzANBgkqhkiG9w0BAQUFAAOB
// SIG // gQCuOhe4SntV+mRV7ECk7UlBkJmcibyvLh3KeCP5HBkP
// SIG // f+tovDLZiDje3D/TibQ/sYKW8aRauu0uJtPefAFuAAoA
// SIG // pAaSEUgJQPkcGHlnIyTgu9XhUK4b9Q7d4C6BzYCjbFJP
// SIG // kXVViroi8tLqQXWIL2NVfR5UWpVZytk0gcBfXvZ6tTCC
// SIG // BPMwggPboAMCAQICEFXvL2VCrn2dIzU3ACqsrQkwDQYJ
// SIG // KoZIhvcNAQEFBQAwgbQxCzAJBgNVBAYTAlVTMRcwFQYD
// SIG // VQQKEw5WZXJpU2lnbiwgSW5jLjEfMB0GA1UECxMWVmVy
// SIG // aVNpZ24gVHJ1c3QgTmV0d29yazE7MDkGA1UECxMyVGVy
// SIG // bXMgb2YgdXNlIGF0IGh0dHBzOi8vd3d3LnZlcmlzaWdu
// SIG // LmNvbS9ycGEgKGMpMDQxLjAsBgNVBAMTJVZlcmlTaWdu
// SIG // IENsYXNzIDMgQ29kZSBTaWduaW5nIDIwMDQgQ0EwHhcN
// SIG // MDYxMDA5MDAwMDAwWhcNMDgxMTA0MjM1OTU5WjCBtjEL
// SIG // MAkGA1UEBhMCVVMxCzAJBgNVBAgTAkNBMRYwFAYDVQQH
// SIG // Ew1TYW4gRnJhbmNpc2NvMRcwFQYDVQQKFA5BdXRvZGVz
// SIG // aywgSW5jLjE+MDwGA1UECxM1RGlnaXRhbCBJRCBDbGFz
// SIG // cyAzIC0gTWljcm9zb2Z0IFNvZnR3YXJlIFZhbGlkYXRp
// SIG // b24gdjIxEDAOBgNVBAsUB0J1enpzYXcxFzAVBgNVBAMU
// SIG // DkF1dG9kZXNrLCBJbmMuMIGfMA0GCSqGSIb3DQEBAQUA
// SIG // A4GNADCBiQKBgQCrreL8W+Wzqt0TH8CxShH6gqSlZ75q
// SIG // EbvekYyyL0gjhqTn8w0XhaxdTyPJCP/vm5kQGlWjqkeF
// SIG // 59Xinl3p4rxuBQLYN8F5IAF2qZoaJFHtEdPU5SOtm5K6
// SIG // ipIJbv6W1VMoMbAxOmkPL3eQ4eJvjMEsW8ZLE7jNLfq7
// SIG // BqmOD1WF+QIDAQABo4IBfzCCAXswCQYDVR0TBAIwADAO
// SIG // BgNVHQ8BAf8EBAMCB4AwQAYDVR0fBDkwNzA1oDOgMYYv
// SIG // aHR0cDovL0NTQzMtMjAwNC1jcmwudmVyaXNpZ24uY29t
// SIG // L0NTQzMtMjAwNC5jcmwwRAYDVR0gBD0wOzA5BgtghkgB
// SIG // hvhFAQcXAzAqMCgGCCsGAQUFBwIBFhxodHRwczovL3d3
// SIG // dy52ZXJpc2lnbi5jb20vcnBhMBMGA1UdJQQMMAoGCCsG
// SIG // AQUFBwMDMHUGCCsGAQUFBwEBBGkwZzAkBggrBgEFBQcw
// SIG // AYYYaHR0cDovL29jc3AudmVyaXNpZ24uY29tMD8GCCsG
// SIG // AQUFBzAChjNodHRwOi8vQ1NDMy0yMDA0LWFpYS52ZXJp
// SIG // c2lnbi5jb20vQ1NDMy0yMDA0LWFpYS5jZXIwHwYDVR0j
// SIG // BBgwFoAUCPVR6Pv+PT1kNnxoz1t4qN+5xTcwEQYJYIZI
// SIG // AYb4QgEBBAQDAgQQMBYGCisGAQQBgjcCARsECDAGAQEA
// SIG // AQH/MA0GCSqGSIb3DQEBBQUAA4IBAQCtQLL10ubxkFkb
// SIG // +/hVG5KRiT/NR67FfPBG3NISirImKZWmReOT+pvzy6mu
// SIG // Xyu9PSBZXEaIp+eqJAF/cDAsMwalTDcsSM4UWqPY5I8F
// SIG // A8edkQvAob16FKO6vqMNaeibEtEvpwO5zHBnGYnMaA0Q
// SIG // vEmSMv7qa/OMhenGKJm2Zsw7zw50NVp/Otn/yBttgAYI
// SIG // b8ZHen3RLOIAodwKahPMpLAjXCZ18kWSp2RmkGuwZst/
// SIG // z55+eMIsHfI1APjuQoBr2nHSFa/RjU+NQ41uj0PWNpPf
// SIG // 0+WrpkTWbOcL1uyQlNIALvWKGWraH++Yw435u3/EiKZI
// SIG // BSVFpN8H4ejDvXSKyWYLMYIEDzCCBAsCAQEwgckwgbQx
// SIG // CzAJBgNVBAYTAlVTMRcwFQYDVQQKEw5WZXJpU2lnbiwg
// SIG // SW5jLjEfMB0GA1UECxMWVmVyaVNpZ24gVHJ1c3QgTmV0
// SIG // d29yazE7MDkGA1UECxMyVGVybXMgb2YgdXNlIGF0IGh0
// SIG // dHBzOi8vd3d3LnZlcmlzaWduLmNvbS9ycGEgKGMpMDQx
// SIG // LjAsBgNVBAMTJVZlcmlTaWduIENsYXNzIDMgQ29kZSBT
// SIG // aWduaW5nIDIwMDQgQ0ECEFXvL2VCrn2dIzU3ACqsrQkw
// SIG // DAYIKoZIhvcNAgUFAKCBljAZBgkqhkiG9w0BCQMxDAYK
// SIG // KwYBBAGCNwIBBDAcBgorBgEEAYI3AgELMQ4wDAYKKwYB
// SIG // BAGCNwIBFTAfBgkqhkiG9w0BCQQxEgQQAgAyqFUFzpbI
// SIG // IzedD7OZ9jA6BgorBgEEAYI3AgEMMSwwKqAogCYAQQB1
// SIG // AHQAbwBkAGUAcwBrACAARABXAEYAIABWAGkAZQB3AGUA
// SIG // cjANBgkqhkiG9w0BAQEFAASBgASaTswVYLvLC5/i2WLi
// SIG // 0HEfNYjdSLOUr4TmjUKebdg4SNeB/BhH+/CzIm5tyuxO
// SIG // uI+2hnTsOO9kOWG0hPQ2Lfdt5FN91NpFocgdRKgCzfjw
// SIG // XuTDCcRiOCJu9KD4hYUo2fc0ioEbR8Q/pkbvKgGv+Ppi
// SIG // EaDb25zcBNlxUof354UyoYIB/zCCAfsGCSqGSIb3DQEJ
// SIG // BjGCAewwggHoAgEBMGcwUzELMAkGA1UEBhMCVVMxFzAV
// SIG // BgNVBAoTDlZlcmlTaWduLCBJbmMuMSswKQYDVQQDEyJW
// SIG // ZXJpU2lnbiBUaW1lIFN0YW1waW5nIFNlcnZpY2VzIENB
// SIG // AhAN6Svw1NgpiBgyBQlemnaIMAwGCCqGSIb3DQIFBQCg
// SIG // WTAYBgkqhkiG9w0BCQMxCwYJKoZIhvcNAQcBMBwGCSqG
// SIG // SIb3DQEJBTEPFw0wNjExMDkyMzE4MzFaMB8GCSqGSIb3
// SIG // DQEJBDESBBBmLJvgQ5FUpnmCkUCgf1xsMA0GCSqGSIb3
// SIG // DQEBAQUABIIBAGnvI0bND+obMVVB/8QKCJW4/Hq/G4bg
// SIG // jOY1PzJWNR53ect4YH1E0Cjzu0FXOz7qH14n0sp4tLWp
// SIG // tZzRY8vAh5N6r10EECSmvfgaOIN3EBgZM8ngYH5hDmpY
// SIG // qEV00q0AmlN/me419cx41OgI1F4tp/KhUZ5JaRNw8WHb
// SIG // tWKTYlacD70zw7YlvuW0qDEbbemW/ZzqGEVGalaJqRMz
// SIG // Z833PT6KsdoqRA3uib9MHEGbXqeoy0J7DTG5iEM08S8k
// SIG // gwMNpHND/vKG3z2Aw59c3I1maEx0v/0K9vBGAZYtvNqP
// SIG // CSqMdqDfjq2X+UUlmCeuSEqYmIRY1ov6GeDK8NDFqoS+hsY=
// SIG // End signature block
